@@ -21,8 +21,8 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(KCMWorkspaceOptionsFactory, "kcm_workspace.json", registerPlugin<KCMWorkspaceOptions>(); registerPlugin<WorkspaceOptionsData>();)
 
-KCMWorkspaceOptions::KCMWorkspaceOptions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : KQuickAddons::ManagedConfigModule(parent, metaData, args)
+KCMWorkspaceOptions::KCMWorkspaceOptions(QObject *parent, const KPluginMetaData &metaData)
+    : KQuickManagedConfigModule(parent, metaData)
     , m_data(new WorkspaceOptionsData(this))
 {
     qmlRegisterAnonymousType<WorkspaceOptionsGlobalsSettings>("org.kde.plasma.workspaceoptions.kcm", 0);
@@ -51,7 +51,7 @@ void KCMWorkspaceOptions::save()
 {
     const bool primarySelectionSaved = m_data->workspaceOptionsKwinSettings()->findItem(QStringLiteral("primarySelection"))->isSaveNeeded();
 
-    ManagedConfigModule::save();
+    KQuickManagedConfigModule::save();
 
     {
         QDBusMessage message = QDBusMessage::createSignal("/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange");
@@ -64,10 +64,10 @@ void KCMWorkspaceOptions::save()
 
     {
         QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/kwinrc"), QStringLiteral("org.kde.kconfig.notify"), QStringLiteral("ConfigChanged"));
-        const QHash<QString, QByteArrayList> changes = {
+        QHash<QString, QByteArrayList> changes = {
             {QStringLiteral("Wayland"), {"EnablePrimarySelection"}},
         };
-        message.setArguments({QVariant::fromValue(changes)});
+        message.setArguments({QVariant::fromValue(std::move(changes))});
         QDBusConnection::sessionBus().send(message);
     }
 
